<?php
/**
 * @package MadIrish-Webmail
 * @author Justin C. Klein Keane
 * @version 2.0
 * 
 * 
 */
require_once($GLOBALS['basedir']."lib/sql.php");
require_once($GLOBALS['basedir']."lib/html.php");

Class AddressBook extends Sql {
	
	/**
	 * Internal array
	 *
	 * @var array
	 */
	var $contacts; //array of contacts
	
	//instantiate the addressbook object
	/**
	 * Initializes Sql() to extend SQL support.
	 *
	 * @return AddressBook
	 */
	function AddressBook() {
		$this->Sql();
	}
	
	/**
	 * Find a person and return an array of their information in
	 * the form:
	 * 	 addressbook_id => []
	 *   addressbook_email => []
	 *   addressbook_name => []
	 *   addressbook_owner => []
	 *   addressbook_email2 => []
	 *   addressbook_firstname => []
	 *   addressbook_lastname => []
	 *   addressbook_address => []
	 *   addressbook_homephone => []
	 *   addressbook_mobilephone => []
	 *   addressbook_officephone => []
	 *   addressbook_im => []
	 *   addressbook_shared => []
	 *
	 * @param string $query Just the where clause for the query.
	 * @return array
	 */
	function getContacts($query) {
		$id = 'addressbook_id';
		$string_lookup_field = 'addressbook_name'; 
		$table = 'addressbook';
		$order_column = 'addressbook_name';
		$lookup_condition = ' (addressbook_shared = 1 OR addressbook_owner = \'' . $this->username . '\') ';
		
		if (is_numeric($query)) {
			//look up a contact based on id
			$lookup_condition .= " AND $id = '$query'";
		}
		elseif (is_array($query)) {
			//look up multiple contacts from the array
			$lookup_condition .= " AND $id IN (" . join(',', $query) . ")";
		}
		elseif (is_string($query)) {
			//lookup up multiple contacts on a string query (wildcard)
			$lookup_condition .= " AND $string_lookup_field like '$query'";
		}
		
		/**
		 * @var string This is select query string that finds the contact in table $table
		 */
		$query_string = 'select * from ' . $table . ' where ' . $lookup_condition . ' order by ' . $order_column;
		
		return $this->selectSQL($query_string);

	}
	
	/**
	 * Display contact information in a table
	 *
	 * @param string contacts Just the where clause for the query.
	 * @return void
	 */
	function displayContacts($contacts) {
		$html = new Html();
		//this function displays the GUI front end of contacts
		foreach ($contacts as $contact) {
			extract($contact);
			print $html->div('contacts','contact',
						$html->table_start('id="contactTable"') . 
						$html->tr(
							$html->td('Display Name:') .
							$html->td($addressbook_name)
						) .
						$html->tr(
							$html->td('First Name:') .
							$html->td($addressbook_firstname)
						)  .
						$html->tr(
							$html->td('Last Name:') .
							$html->td($addressbook_lastname)
						)  .
						$html->tr(
							$html->td('E-mail:') .
							$html->td($addressbook_email)
						)  .
						$html->tr(
							$html->td('Secondary E-mail:') .
							$html->td($addressbook_email2)
						)  .
						$html->tr(
							$html->td('Address:', 'valign="top"') .
							$html->td($html->textarea('address', $addressbook_address))
						)  .
						$html->tr(
							$html->td('Home Phone:') .
							$html->td($addressbook_homephone)
						)  .
						$html->tr(
							$html->td('Cell Phone:') .
							$html->td($addressbook_mobilephone)
						)  .
						$html->tr(
							$html->td('Office Phone:') .
							$html->td($addressbook_officephone)
						)  .
						$html->tr(
							$html->td('IM:') .
							$html->td($addressbook_im)
						)  .
						$html->tr(
							$html->td( $html->a('?edit='.$addressbook_id,'Edit')) .
							$html->td( $html->a('?delete='.$addressbook_id,'Delete'))
						) .
						$html->table_end()
			);			
		}
	}
	
	function displayContactList($contacts) {
		$i=0;
		$mod = intval(count($contacts)/4);

		print "<table id='fullContactListTable'><tr>\n";
		foreach ($contacts as $contact) {
			extract($contact);
			if ($i == 0) 
				print "<td valign='top'>";
				
			print "<div id='person'>" . $this->a("?contact=$addressbook_name", $addressbook_name . " ") . "<br/>$addressbook_email</div><br/>";	
			
			$i++;
			
			if ($i%$mod == 0) {
				print "</td>\n";
				$i=0;
			}
			
		}
		
		print "</tr></table>\n";
	}
	
	function displayDropList($formName, $fieldName, $target) {
		//get a list of emails and display names
		$nameValues = $this->getNameEmailList();
		foreach ($nameValues as $row) 
			$list[$row['email']] = $row['name'];
			
		$retval =  $this->button("value='<' onclick='moveAddy(\"$formName\",\"$fieldName\",\"$target\")'");
		$retval .= $this->select($list,"name='$fieldName'");
		return $retval;
	}
	
	function getNameEmailList() {
		//return an array of email addresses and display names
		$query = "select addressbook_email AS email, addressbook_name AS name from addressbook where addressbook_owner = '$this->username' or addressbook_shared = 1 order by addressbook_name";
		return $this->selectSQL($query);
	}
	
	function addContact($array) {
		$sql = "INSERT INTO addressbook (" .
	    join(",", array_keys($array) ) .
	    ") VALUES ('" .
	    join("','", $array) .
	    "')";
	    $this->iudSQL($sql);
	}
	
	function updateContact($array,$id) {
		foreach ($array as $key=>$val) 
			$updateString .= "$key = '$val', ";
		$updateString = substr($updateString,0,-2);
		$sql = "update addressbook set $updateString where addressbook_id = $id";
		$this->iudSQL($sql);
	}
	
	function dropContact($id) {
		$sql = "delete from addressbook where addressbook_id = '$id' and addressbook_owner = '" . $this->username . "'";
	    $this->iudSQL($sql);
	}
	
	function displayContactForm($id='') {
		$action = 'add=yes';
		if ($id != '') {
			$details = $this->getContacts($id);
			$action = 'update=' . $id;
			extract($details[0]);
		}	 
		print "<form method='post' action='?$action'>\n";
			print "<table id='contactTable'>\n";
			print "<tr><td>Display Name:</td><td><input type='text' name='addressbook_name' value='$addressbook_name'/></td></tr>\n";
			print "<tr><td>First Name:</td><td><input type='text' name='addressbook_firstname' value='$addressbook_firstname'/></td></tr>\n";
			print "<tr><td>Last Name:</td><td><input type='text' name='addressbook_lastname' value='$addressbook_lastname'/></td></tr>\n";
			print "<tr><td>E-mail:</td><td><input type='text' name='addressbook_email' value='$addressbook_email'/></td></tr>\n";
			print "<tr><td>Secondary E-mail:</td><td><input type='text' name='addressbook_email2' value='$addressbook_email2'/></td></tr>\n";
			print "<tr><td valign='top'>Address:</td><td>" . $this->textarea('addressbook_address', $addressbook_address) . "</td></tr>\n";
			print "<tr><td>Home Phone:</td><td><input type='text' name='addressbook_homephone' value='$addressbook_homephone'/></td></tr>\n";
			print "<tr><td>Cell Phone:</td><td><input type='text' name='addressbook_mobilephone' value='$addressbook_mobilephone'/></td></tr>\n";
			print "<tr><td>Office Phone:</td><td><input type='text' name='addressbook_officephone' value='$addressbook_officephone'/></td></tr>\n";
			print "<tr><td>IM:</td><td><input type='text' name='addressbook_im' value='$addressbook_im'/></td></tr>\n";
			print "<tr><td>Shared?:</td><td><select name='addressbook_shared'>\n\t<option value='0'";
				if ($addressbook_shared != 1) print " selected";
			print ">No</option>\n\t<option value='1'";
				if ($addressbook_shared ==1) print " selected";
			print ">Yes</option></select></td></tr>\n";
			print "</table>\n";
			print "<input type='hidden' name='addressbook_owner' value='" . $this->username . "'/>\n";
			print "<input type='submit'/>\n";
		print "</form>\n";
	}
}

?>