<?php
/**
 * Class Calendar
 * 
 * 
 * @package MadIrish-Webmail
 * @author Justin C. Klein Keane
 * @version 2.0
 * 
 * Sample use:
 * <code>
 * $calendar = new Calendar();
 * echo "<style type='text/css'>td#highlight { background-color:yellow; }</style>\n";
 * $calendar->showCalendarNav();
 * $calendar->showMonth();
 * </code>
 * 
 */


require_once ($GLOBALS['basedir']."lib/common.php");

Class Calendar extends Common {
	//properties
	/**
	 * @var int
	 */
	var $month;
	/**
	 * @var string
	 */
	var $month_name;
	/**
	 * @var int
	 */
	var $day;
	/**
	 * @var int
	 */
	var $year;
	/**
	 * Number of the day on which the first of the month
	 * occurs
	 *
	 * @var int(6)
	 */
	var $first_of_the_month; //0-6 what day it occurs on
	/**
	 * @var int
	 */
	var $days_in_the_month;
	/**
	 * Days to be highlighted in the display.  Array of integers
	 * corresponding to days of the month.
	 *
	 * @var array
	 */
	var $highlight_days = array(); //array of days to id as special
	
	/**
	 * True / False - href the day numbers
	 * @var bit
	 */
	var $href_day = 1;  //1=true 0=false
	/**
	 * Used in case you want other url variables passed.
	 *
	 * @var string
	 */
	var $href_day_url_root = '?';
	/**
	 * Used for the CSS.  $calendar_id is the id of the table painted when showCalendar() is called.
	 * @see showCalendar()
	 *
	 * @var int
	 */
	var $calendar_id = 'calendar';
	
	/**
	 * Sets up proper variables for display.
	 * 
	 * Calendar() merely checks to see if there
	 * are any $_REQUEST variables that the day, month, and year should
	 * be set to, otherwise today is used.  Also lays out the month name, 
	 * the first of the month and the total number of days in the month
	 * for layout.
	 *
	 * @return void
	 */
	function Calendar() {
		if (! isset($this->month) && ! isset($_REQUEST['month'])) 
			$this->month = date('m');
		else 
			$this->month = $_REQUEST['month'];
			
		if (! isset($this->day) && ! isset($_REQUEST['day'])) 
			$this->day = date('d');
		else 
			$this->day = $_REQUEST['day'];
		
		if (! isset($this->year) && ! isset($_REQUEST['year'])) 
			$this->year = date('Y');
		else 
			$this->year = $_REQUEST['year'];
			
		$this->month_name = date('F', mktime(0,0,0,$this->month,$this->day,$this->year) );
		$this->first_of_the_month = date('w', mktime(0,0,0,$this->month,1,$this->year) ) +1;
		$this->days_in_the_month = date('t', mktime(0,0,0,$this->month,1,$this->year) );
	}
	
	/**
	 * showMonth() is simply the display function, putting the calendar 
	 * table on the page.
	 * 
	 * @uses Html
	 *
	 */
	function showMonth() {
		$first_of_the_month = $this->first_of_the_month;
		new Html();
		$retval .= $this->h(4,$this->month_name . ', ' . $this->year);
		$retval .= $this->table_start('border="1" id="' . $this->calendar_id . '"');
		$retval .= $this->tr( $this->td('Sun') . 
						$this->td('Mon') . 
						$this->td('Tues') . 
						$this->td('Wed') . 
						$this->td('Thu') . 
						$this->td('Fri') . 
						$this->td('Sat')  );
		$dayCounter = 1;
		
		while( $dayCounter < $this->days_in_the_month ) {
			//print the week;
			$td_days = '';
			for ($x=0; $x<7; $x++) {
				if ( ($dayCounter < $first_of_the_month) || ($dayCounter > $this->days_in_the_month) ) {
					$td_days .= $this->td( '&nbsp;','class="gray"');
					$first_of_the_month--;
				}
				else { 
					//hyperlink the day?
					if ($this->href_day = 1)
						$day_link = $this->a($this->href_day_url_root."day=$dayCounter&month=".intval($this->month)."&year=".$this->year, $dayCounter);
					else 
						$day_link = $dayCounter;
					
					//highlight the day
					if (! (array_search($dayCounter, $this->highlight_days) === false) ) 
						$cell_id = 'highlight';
					else 
						$cell_id = 'normal';
						
					$td_days .= $this->td($day_link, 'id="' . $cell_id . '"');
					$dayCounter++;
				}
			}
			$retval .= $this->tr( $td_days );
		}
		$retval .= $this->table_end();
		
		return $retval;
	}
	/**
	 * showCalendarNav() puts navigation buttons in a table that
	 * can appear on the same page as the calendar.  The buttons
	 * alter URL variables.
	 *
	 */
	function showCalendarNav() {
			$next_year = $prev_year = $this->year;
			$next_month = $this->month +1;
			$prev_month = $this->month-1;
			
			if ($next_month>12) {
				$next_month=1;
				$next_year++;
			}
			if ($prev_month<1) { 
				$prev_month=12;
				$prev_year--;	
			}
			$next_link = $this->href_day_url_root."month=".intval($next_month)."&year=".$next_year;
			$prev_link = $this->href_day_url_root."month=".intval($prev_month)."&year=".$prev_year;
			
			$retval .= $this->table_start('id="calendarNav"');
				$retval .= $this->tr( $this->td(
									$this->button(" value='<' onclick='location.href=\"$prev_link\"'")) . 
								$this->td(
									$this->button(" value='>' onclick='location.href=\"$next_link\"'")) 
					  );
			$retval .= $this->table_end();
			return $retval;
	}
}

?>